@@ -62,6 +62,10 @@ class Network(ReloadableObjectFromJson):
     def _parse_json_object(self, json_object: Dict[str, Any]) -> NetworkInspectResult:
         return NetworkInspectResult.parse_obj(json_object)
 
+    def _get_inspect_result(self) -> NetworkInspectResult:
+        """Only there to allow tools to know the return type"""
+        return super()._get_inspect_result()
+
     @property
     def name(self) -> str:
         return self._get_inspect_result().name
